summaryrefslogtreecommitdiff
path: root/svx/source/svdraw/svdfmtf.cxx
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2016-09-02 10:53:14 +0200
committerNoel Grandin <noel@peralex.com>2016-09-05 08:21:46 +0200
commit12569802394fb0a9850fcdb0647a0845a803f1ff (patch)
tree9f5a626852adbf00378fc3dc80475ad896d957f8 /svx/source/svdraw/svdfmtf.cxx
parent933c0679d64a5585ebfd233180a1a818b493eec5 (diff)
convert GradientStyle to scoped enum
Change-Id: Ib740da708612df7a5f4b8c82262b9b1bd436604d
Diffstat (limited to 'svx/source/svdraw/svdfmtf.cxx')
-rw-r--r--svx/source/svdraw/svdfmtf.cxx18
1 files changed, 9 insertions, 9 deletions
diff --git a/svx/source/svdraw/svdfmtf.cxx b/svx/source/svdraw/svdfmtf.cxx
index aad00cae4399..a19a53422688 100644
--- a/svx/source/svdraw/svdfmtf.cxx
+++ b/svx/source/svdraw/svdfmtf.cxx
@@ -1357,18 +1357,18 @@ namespace
switch(rGradientStyle)
{
- case GradientStyle_LINEAR: aXGradientStyle = css::awt::GradientStyle_LINEAR; break;
- case GradientStyle_AXIAL: aXGradientStyle = css::awt::GradientStyle_AXIAL; break;
- case GradientStyle_RADIAL: aXGradientStyle = css::awt::GradientStyle_RADIAL; break;
- case GradientStyle_ELLIPTICAL: aXGradientStyle = css::awt::GradientStyle_ELLIPTICAL; break;
- case GradientStyle_SQUARE: aXGradientStyle = css::awt::GradientStyle_SQUARE; break;
- case GradientStyle_RECT: aXGradientStyle = css::awt::GradientStyle_RECT; break;
-
- // Needed due to GradientStyle_FORCE_EQUAL_SIZE; this again is needed
+ case GradientStyle::Linear: aXGradientStyle = css::awt::GradientStyle_LINEAR; break;
+ case GradientStyle::Axial: aXGradientStyle = css::awt::GradientStyle_AXIAL; break;
+ case GradientStyle::Radial: aXGradientStyle = css::awt::GradientStyle_RADIAL; break;
+ case GradientStyle::Elliptical: aXGradientStyle = css::awt::GradientStyle_ELLIPTICAL; break;
+ case GradientStyle::Square: aXGradientStyle = css::awt::GradientStyle_SQUARE; break;
+ case GradientStyle::Rect: aXGradientStyle = css::awt::GradientStyle_RECT; break;
+
+ // Needed due to GradientStyle::FORCE_EQUAL_SIZE; this again is needed
// to force the enum defines in VCL to a defined size for the compilers,
// so despite it is never used it cannot be removed (would break the
// API implementation probably).
- case GradientStyle_FORCE_EQUAL_SIZE: break;
+ case GradientStyle::FORCE_EQUAL_SIZE: break;
default:
break;
}